"use strict";

exports.__esModule = true;
exports.default = void 0;

var _core = require("@superset-ui/core");

var _TimeFormats = _interopRequireWildcard(require("./TimeFormats"));

var _createD3TimeFormatter = _interopRequireDefault(require("./factories/createD3TimeFormatter"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

class TimeFormatterRegistry extends _core.RegistryWithDefaultKey {
  constructor() {
    super({
      initialDefaultKey: _TimeFormats.default.DATABASE_DATETIME,
      name: 'TimeFormatter',
      overwritePolicy: _core.OverwritePolicy.WARN
    });
  }

  get(format) {
    const targetFormat = ("" + (format === null || typeof format === 'undefined' || format === '' ? this.defaultKey : format)).trim();

    if (this.has(targetFormat)) {
      return super.get(targetFormat);
    } // Create new formatter if does not exist


    const useLocalTime = targetFormat.startsWith(_TimeFormats.LOCAL_PREFIX);
    const formatString = targetFormat.replace(_TimeFormats.LOCAL_PREFIX, '');
    const formatter = (0, _createD3TimeFormatter.default)({
      formatString,
      useLocalTime
    });
    this.registerValue(targetFormat, formatter);
    return formatter;
  }

  format(format, value) {
    return this.get(format)(value);
  }

}

exports.default = TimeFormatterRegistry;